"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CrashDetails = exports.DefectTrackerType = exports.ProcessingStatus = void 0;
var _crash_1 = require("@crash");
var _events_1 = require("@events");
var argument_contracts_1 = __importDefault(require("argument-contracts"));
var ProcessingStatus;
(function (ProcessingStatus) {
    ProcessingStatus[ProcessingStatus["Processing"] = 0] = "Processing";
    ProcessingStatus[ProcessingStatus["ActiveThreadComplete"] = 1] = "ActiveThreadComplete";
    ProcessingStatus[ProcessingStatus["Complete"] = 2] = "Complete";
})(ProcessingStatus = exports.ProcessingStatus || (exports.ProcessingStatus = {}));
var DefectTrackerType;
(function (DefectTrackerType) {
    DefectTrackerType["None"] = "None";
    DefectTrackerType["FogBugz"] = "FogBugz";
    DefectTrackerType["Jira"] = "Jira";
    DefectTrackerType["Azure"] = "Azure DevOps";
    DefectTrackerType["YouTrack"] = "YouTrack";
    DefectTrackerType["GitHub"] = "GitHub";
    DefectTrackerType["Assembla"] = "Assembla";
})(DefectTrackerType = exports.DefectTrackerType || (exports.DefectTrackerType = {}));
function defaultToEmptyString(value, name) {
    if (value) {
        argument_contracts_1.default.assertString(value, name);
        return value;
    }
    else {
        return '';
    }
}
var CrashDetails = (function () {
    function CrashDetails(options) {
        argument_contracts_1.default.assertNumber(options.processed, 'options.processed');
        argument_contracts_1.default.assertNumber(options.id, 'options.id');
        argument_contracts_1.default.assertNumber(options.stackKeyId, 'options.stackKeyId');
        argument_contracts_1.default.assertBoolean(options.missingSymbols, 'options.missingSymbols');
        var safeAppName = defaultToEmptyString(options.appName, 'options.appName');
        var safeAppVersion = defaultToEmptyString(options.appVersion, 'options.appVersion');
        var safeAppKey = defaultToEmptyString(options.appKey, 'options.appKey');
        var safeNotes = defaultToEmptyString(options.comments, 'options.comments');
        var safeCrashTime = defaultToEmptyString(options.crashTime, 'options.crashTime');
        var safeDefectLabel = defaultToEmptyString(options.defectLabel, 'options.defectLabel');
        var safeDefectUrl = defaultToEmptyString(options.defectUrl, 'options.defectUrl');
        var safeDescription = defaultToEmptyString(options.description, 'options.description');
        var safeDumpfile = defaultToEmptyString(options.dumpfile, 'options.dumpfile');
        var safeEmail = defaultToEmptyString(options.email, 'options.email');
        var safeExceptionCode = defaultToEmptyString(options.exceptionCode, 'options.exceptionCode');
        var safeExceptionMessage = defaultToEmptyString(options.exceptionMessage, 'options.exceptionMessage');
        var safeIpAddress = defaultToEmptyString(options.ipAddress, 'options.ipAddress');
        var safePlatform = defaultToEmptyString(options.platform, 'options.platform');
        var safeProcessor = defaultToEmptyString(options.processor, 'options.processor');
        var safeStackKeyDefectLabel = defaultToEmptyString(options.stackKeyDefectLabel, 'options.stackKeyDefectLabel');
        var safeStackKeyDefectUrl = defaultToEmptyString(options.stackKeyDefectUrl, 'options.stackKeyDefectUrl');
        var safeUser = defaultToEmptyString(options.user, 'options.user');
        argument_contracts_1.default.assertType(options.thread, _crash_1.ThreadCollection, 'options.thread');
        argument_contracts_1.default.assertType(options.additionalFiles, Array, 'options.additionalFiles');
        this.additionalFiles = options.additionalFiles;
        this.appKey = safeAppKey;
        this.appName = safeAppName;
        this.appVersion = safeAppVersion;
        this.comments = safeNotes;
        this.crashTime = safeCrashTime;
        this.defectTrackerType = options.defectTrackerType;
        this.defectLabel = safeDefectLabel;
        this.defectUrl = safeDefectUrl;
        this.description = safeDescription;
        this.dumpfile = safeDumpfile;
        this.email = safeEmail;
        this.events = (0, _events_1.convertEventsToEventStreamEvents)(options.events);
        this.exceptionCode = safeExceptionCode;
        this.exceptionMessage = safeExceptionMessage;
        this.id = options.id;
        this.ipAddress = safeIpAddress;
        this.missingSymbols = options.missingSymbols;
        this.nextCrashId = options.nextCrashId;
        this.platform = safePlatform;
        this.previousCrashId = options.previousCrashId;
        this.processed = options.processed;
        this.processor = safeProcessor;
        this.stackKeyId = options.stackKeyId;
        this.stackKeyDefectLabel = safeStackKeyDefectLabel;
        this.stackKeyDefectUrl = safeStackKeyDefectUrl;
        this.thread = new _crash_1.GroupableThreadCollection(__assign(__assign({}, options.thread), { stackKeyId: options.stackKeyId }));
        this.user = safeUser;
        this.additionalInfo = _crash_1.AdditionalInfo.fromRawResponse(options.debuggerOutput);
        Object.freeze(this);
    }
    return CrashDetails;
}());
exports.CrashDetails = CrashDetails;
//# sourceMappingURL=crash-details.js.map