import { OrderFilter } from '@common';
export class TableDataFormDataBuilder {
    _formDataFactory;
    _formParts;
    constructor(_formDataFactory, _formParts = {}) {
        this._formDataFactory = _formDataFactory;
        this._formParts = _formParts;
    }
    withColumnGroups(groups) {
        if (groups) {
            let groupsCount = 0;
            groups.forEach((group, i) => {
                this._formParts[`group${i}`] = group;
                groupsCount++;
            });
            this._formParts['groupscount'] = groupsCount;
        }
        return this;
    }
    withFilterGroups(groups) {
        if (groups) {
            let filtersCount = 0;
            groups.forEach((group) => {
                if (group.filters.length) {
                    group.filters.forEach((filter, i) => {
                        const firstFilter = i === 0;
                        const lastFilter = i === group.filters.length - 1;
                        this._formParts[`filtergroupopen${filtersCount}`] = firstFilter ? 1 : 0;
                        this._formParts[`filteroperator${filtersCount}`] = firstFilter ? group.groupOperator?.value : group.filterOperator?.value;
                        this._formParts[`filterdatafield${filtersCount}`] = filter.filterDataField;
                        this._formParts[`filtercondition${filtersCount}`] = filter.filterCondition;
                        this._formParts[`filtervalue${filtersCount}`] = filter.filterValue;
                        this._formParts[`filtergroupclose${filtersCount}`] = lastFilter ? 1 : 0;
                        filtersCount++;
                    });
                }
            });
            this._formParts['filterscount'] = filtersCount;
        }
        return this;
    }
    withPage(page = 0) {
        this._formParts.pagenum = page;
        return this;
    }
    withPageSize(pageSize = 10) {
        this._formParts.pagesize = pageSize;
        return this;
    }
    withSortColumn(sortColumn) {
        if (sortColumn) {
            this._formParts.sortdatafield = sortColumn;
        }
        return this;
    }
    withSortOrder(sortOrder) {
        if (sortOrder) {
            let translatedSortOrder;
            if (sortOrder === OrderFilter.none) {
                return this;
            }
            else if (sortOrder === OrderFilter.ascending) {
                translatedSortOrder = 'asc';
            }
            else if (sortOrder === OrderFilter.descending) {
                translatedSortOrder = 'desc';
            }
            this._formParts.sortorder = translatedSortOrder;
        }
        return this;
    }
    withDatabase(database) {
        if (database) {
            this._formParts.database = database;
        }
        return this;
    }
    withApplications(applications) {
        if (applications && applications.length) {
            this._formParts.appNames = applications.join(',');
        }
        return this;
    }
    withVersions(versions) {
        if (versions && versions.length) {
            this._formParts.versions = versions.join(',');
        }
        return this;
    }
    build() {
        const formData = this._formDataFactory();
        Object.entries(this._formParts).forEach(urlPart => formData.append(urlPart[0], `${urlPart[1]}`));
        return formData;
    }
}
//# sourceMappingURL=table-data-form-data-builder.js.map