import { CrashDetails } from '@crash';
import ac from 'argument-contracts';
export class CrashApiClient {
    _client;
    constructor(_client) {
        this._client = _client;
    }
    async getCrashById(database, crashId) {
        ac.assertNonWhiteSpaceString(database, 'database');
        if (crashId <= 0) {
            throw new Error(`Expected id to be a positive non-zero number. Value received: "${crashId}"`);
        }
        const formData = this._client.createFormData();
        formData.append('database', database);
        formData.append('id', crashId.toString());
        const init = {
            method: 'POST',
            body: formData,
            cache: 'no-cache',
            credentials: 'include',
            redirect: 'follow'
        };
        const response = await this._client.fetch('/api/crash/data', init);
        const json = await response.json();
        if (response.status !== 200) {
            throw new Error(json.message);
        }
        return new CrashDetails(json);
    }
    async reprocessCrash(database, crashId, force = false) {
        ac.assertNonWhiteSpaceString(database, 'database');
        ac.assertBoolean(force, 'force');
        if (crashId <= 0) {
            throw new Error(`Expected id to be a positive non-zero number. Value received: "${crashId}"`);
        }
        const formData = this._client.createFormData();
        formData.append('database', database);
        formData.append('id', crashId.toString());
        formData.append('force', force.toString());
        const init = {
            method: 'POST',
            body: formData,
            cache: 'no-cache',
            credentials: 'include',
            redirect: 'follow'
        };
        const response = await this._client.fetch('/api/crash/reprocess', init);
        const json = await response.json();
        if (response.status !== 202) {
            throw new Error(json.message);
        }
        return json;
    }
}
//# sourceMappingURL=crash-api-client.js.map