import { AdditionalInfo, GroupableThreadCollection, ThreadCollection } from '@crash';
import { convertEventsToEventStreamEvents } from '@events';
import ac from 'argument-contracts';
export var ProcessingStatus;
(function (ProcessingStatus) {
    ProcessingStatus[ProcessingStatus["Processing"] = 0] = "Processing";
    ProcessingStatus[ProcessingStatus["ActiveThreadComplete"] = 1] = "ActiveThreadComplete";
    ProcessingStatus[ProcessingStatus["Complete"] = 2] = "Complete";
})(ProcessingStatus || (ProcessingStatus = {}));
export var DefectTrackerType;
(function (DefectTrackerType) {
    DefectTrackerType["None"] = "None";
    DefectTrackerType["FogBugz"] = "FogBugz";
    DefectTrackerType["Jira"] = "Jira";
    DefectTrackerType["Azure"] = "Azure DevOps";
    DefectTrackerType["YouTrack"] = "YouTrack";
    DefectTrackerType["GitHub"] = "GitHub";
    DefectTrackerType["Assembla"] = "Assembla";
})(DefectTrackerType || (DefectTrackerType = {}));
function defaultToEmptyString(value, name) {
    if (value) {
        ac.assertString(value, name);
        return value;
    }
    else {
        return '';
    }
}
export class CrashDetails {
    processed;
    additionalFiles;
    appKey;
    appName;
    appVersion;
    comments;
    crashTime;
    defectTrackerType;
    defectId;
    defectLabel;
    defectUrl;
    description;
    dumpfile;
    email;
    events;
    exceptionCode;
    exceptionMessage;
    id;
    ipAddress;
    missingSymbols;
    nextCrashId;
    platform;
    previousCrashId;
    processor;
    stackKeyId;
    stackKeyDefectId;
    stackKeyDefectLabel;
    stackKeyDefectUrl;
    thread;
    user;
    additionalInfo;
    constructor(options) {
        ac.assertNumber(options.processed, 'options.processed');
        ac.assertNumber(options.id, 'options.id');
        ac.assertNumber(options.stackKeyId, 'options.stackKeyId');
        ac.assertBoolean(options.missingSymbols, 'options.missingSymbols');
        const safeAppName = defaultToEmptyString(options.appName, 'options.appName');
        const safeAppVersion = defaultToEmptyString(options.appVersion, 'options.appVersion');
        const safeAppKey = defaultToEmptyString(options.appKey, 'options.appKey');
        const safeNotes = defaultToEmptyString(options.comments, 'options.comments');
        const safeCrashTime = defaultToEmptyString(options.crashTime, 'options.crashTime');
        const safeDefectLabel = defaultToEmptyString(options.defectLabel, 'options.defectLabel');
        const safeDefectUrl = defaultToEmptyString(options.defectUrl, 'options.defectUrl');
        const safeDescription = defaultToEmptyString(options.description, 'options.description');
        const safeDumpfile = defaultToEmptyString(options.dumpfile, 'options.dumpfile');
        const safeEmail = defaultToEmptyString(options.email, 'options.email');
        const safeExceptionCode = defaultToEmptyString(options.exceptionCode, 'options.exceptionCode');
        const safeExceptionMessage = defaultToEmptyString(options.exceptionMessage, 'options.exceptionMessage');
        const safeIpAddress = defaultToEmptyString(options.ipAddress, 'options.ipAddress');
        const safePlatform = defaultToEmptyString(options.platform, 'options.platform');
        const safeProcessor = defaultToEmptyString(options.processor, 'options.processor');
        const safeStackKeyDefectLabel = defaultToEmptyString(options.stackKeyDefectLabel, 'options.stackKeyDefectLabel');
        const safeStackKeyDefectUrl = defaultToEmptyString(options.stackKeyDefectUrl, 'options.stackKeyDefectUrl');
        const safeUser = defaultToEmptyString(options.user, 'options.user');
        ac.assertType(options.thread, ThreadCollection, 'options.thread');
        ac.assertType(options.additionalFiles, Array, 'options.additionalFiles');
        this.additionalFiles = options.additionalFiles;
        this.appKey = safeAppKey;
        this.appName = safeAppName;
        this.appVersion = safeAppVersion;
        this.comments = safeNotes;
        this.crashTime = safeCrashTime;
        this.defectTrackerType = options.defectTrackerType;
        this.defectLabel = safeDefectLabel;
        this.defectUrl = safeDefectUrl;
        this.description = safeDescription;
        this.dumpfile = safeDumpfile;
        this.email = safeEmail;
        this.events = convertEventsToEventStreamEvents(options.events);
        this.exceptionCode = safeExceptionCode;
        this.exceptionMessage = safeExceptionMessage;
        this.id = options.id;
        this.ipAddress = safeIpAddress;
        this.missingSymbols = options.missingSymbols;
        this.nextCrashId = options.nextCrashId;
        this.platform = safePlatform;
        this.previousCrashId = options.previousCrashId;
        this.processed = options.processed;
        this.processor = safeProcessor;
        this.stackKeyId = options.stackKeyId;
        this.stackKeyDefectLabel = safeStackKeyDefectLabel;
        this.stackKeyDefectUrl = safeStackKeyDefectUrl;
        this.thread = new GroupableThreadCollection({
            ...options.thread,
            stackKeyId: options.stackKeyId,
        });
        this.user = safeUser;
        this.additionalInfo = AdditionalInfo.fromRawResponse(options.debuggerOutput);
        Object.freeze(this);
    }
}
//# sourceMappingURL=crash-details.js.map