import ac from 'argument-contracts';
const splitRegex = /(\\|\/)/;
export class StackFrame {
    fileName;
    functionName;
    lineNumber;
    stackFrameLevel;
    arguments;
    locals;
    constructor(options) {
        let fileName = options.fileName;
        if (fileName) {
            ac.assertString(options.fileName, 'options.fileName');
        }
        else {
            fileName = '';
        }
        let functionName = options.functionName;
        if (functionName) {
            ac.assertString(options.functionName, 'options.functionName');
        }
        else {
            functionName = '';
        }
        let lineNumber = options.lineNumber;
        if (lineNumber) {
            ac.assertNumber(options.lineNumber, 'options.lineNumber');
        }
        else {
            lineNumber = undefined;
        }
        let stackFrameLevel = options.stackFrameLevel;
        if (stackFrameLevel) {
            ac.assertNumber(options.stackFrameLevel, 'options.stackFrameLevel');
        }
        else {
            stackFrameLevel = undefined;
        }
        let args = options.arguments || [];
        if (!Array.isArray(args)) {
            args = [args];
        }
        let locals = options.locals || [];
        if (!Array.isArray(locals)) {
            locals = [locals];
        }
        this.fileName = fileName;
        this.functionName = functionName;
        this.lineNumber = lineNumber;
        this.stackFrameLevel = stackFrameLevel;
        this.arguments = args;
        this.locals = locals;
        Object.freeze(this);
    }
    getDescription() {
        if (this.functionName && !this.lineNumber) {
            return `${this.functionName}`;
        }
        if (this.functionName && this.lineNumber) {
            return `${this.functionName}(${this.lineNumber})`;
        }
        return 'Unknown';
    }
    getLocation() {
        if (this.fileName && !this.lineNumber) {
            return `${this.getShortFileName(this.fileName)}`;
        }
        if (this.fileName && this.lineNumber) {
            return `${this.getShortFileName(this.fileName)}(${this.lineNumber})`;
        }
        return '';
    }
    getShortFileName(fileName) {
        return fileName?.split(splitRegex).pop() ?? '';
    }
}
//# sourceMappingURL=stack-frame.js.map