import { S3ApiClient } from '@common';
import { lastValueFrom, timer } from 'rxjs';
export class SymbolsApiClient {
    _client;
    route = '/api/symbols';
    _s3ApiClient;
    _timer = timer;
    constructor(_client) {
        this._client = _client;
        this._s3ApiClient = new S3ApiClient();
    }
    async deleteSymbols(database, application, version) {
        const route = `${this.route}?dbName=${database}&appName=${application}&appVersion=${version}`;
        const init = {
            method: 'DELETE',
            cache: 'no-cache',
            credentials: 'include',
            redirect: 'follow'
        };
        const response = await this._client.fetch(route, init);
        if (response.status !== 200) {
            throw new Error(`Error deleting symbols for ${database}-${application}-${version} status ${response.status}`);
        }
        const json = await response.json();
        if (json.Status === 'Failed') {
            throw new Error(json.Error);
        }
        return response;
    }
    async postSymbols(database, application, version, files) {
        const promises = files
            .map(async (file) => {
            const name = file.name;
            const size = file.size;
            const presignedUrl = await this.getPresignedUrl(database, application, version, size, name);
            const response = await this._s3ApiClient.uploadFileToPresignedUrl(presignedUrl, file);
            await lastValueFrom(this._timer(1000));
            return response;
        });
        return Promise.all(promises);
    }
    async getPresignedUrl(dbName, appName, appVersion, size, symFileName) {
        const formData = this._client.createFormData();
        formData.append('dbName', dbName);
        formData.append('appName', appName);
        formData.append('appVersion', appVersion);
        formData.append('size', size.toString());
        formData.append('symFileName', symFileName);
        const init = {
            method: 'POST',
            body: formData,
            cache: 'no-cache',
            credentials: 'include',
            redirect: 'follow'
        };
        const response = await this._client.fetch(this.route, init);
        if (response.status !== 200) {
            throw new Error(`Error getting presignedUrl for ${symFileName}`);
        }
        const json = await response.json();
        if (json.Status === 'Failed') {
            throw new Error(json.Error);
        }
        return json.url;
    }
}
//# sourceMappingURL=symbols-api-client.js.map